﻿// <copyright file="X11ServerData.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> X11ServerData.
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version>  0.80, 11/26/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;

namespace Eunomia.SSH2.Channel
{
    /// <summary>
    /// X11ServerData.  Stored data for an x11 forwarding target.
    /// </summary>
    public class X11ServerData
    {
        private string hostName;
        private int port;
        private byte[] x11MagicCookie;
        
        /// <summary>
        /// Gets or sets the hostName that we are forwarding to.
        /// </summary>
        public string HostName
        {
            get { return this.hostName; }
            set { this.hostName = value; }
        }
        
        /// <summary>
        /// Gets or sets the port that we are forwarding to.
        /// </summary>
        public int Port
        {
            get { return this.port; }
            set { this.port = value; }
        }
        
        /// <summary>
        /// Gets or sets the 'magic cookie' associated with this forward.
        /// </summary>
        [SuppressMessage("Microsoft.Performance", "CA1819:PropertiesShouldNotReturnArrays",
                        Justification = "No other way to make this work.")]
        public byte[] X11MagicCookie
        {
            get { return this.x11MagicCookie; }
            set { this.x11MagicCookie = value; }
        }
    }
}