﻿// <copyright file="ConnectionInfo.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> ConnectionInfo
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;

namespace Eunomia.SSH2
{
    /// <summary>
    /// A class that holds the details related to a Connection.
    /// </summary>
    public class ConnectionInfo
    {
        private string keyExchangeAlgorithm;
        private string clientToServerCryptoAlgorithm;
        private string serverToClientCryptoAlgorithm;
        private string clientToServerMACAlgorithm;
        private string serverToClientMACAlgorithm;
        private string serverHostkeyAlgorithm;
        private byte[] serverHostkey;
        private int keyExchangeCounter;
        
        /// <summary>
        /// Gets or sets the key exchange (KEX) algorithm used in the latest key exchange.
        /// </summary>
        public string KeyExchangeAlgorithm
        {
            get { return this.keyExchangeAlgorithm; }
            set { this.keyExchangeAlgorithm = value; }
        }

        /// <summary>
        /// Gets or sets the currently used crypto algorithm for packets from to the client to the
        /// server.
        /// </summary>
        public string ClientToServerCryptoAlgorithm
        {
            get { return this.clientToServerCryptoAlgorithm; }
            set { this.clientToServerCryptoAlgorithm = value; }
        }
        
        /// <summary>
        /// Gets or sets the currently used crypto algorithm for packets from to the server to the
        /// client.
        /// </summary>
        public string ServerToClientCryptoAlgorithm
        {
            get { return this.serverToClientCryptoAlgorithm; }
            set { this.serverToClientCryptoAlgorithm = value; }
        }
        
        /// <summary>
        /// Gets or sets the currently used MAC algorithm for packets from to the client to the
        /// server.
        /// </summary>
        public string ClientToServerMACAlgorithm
        {
            get { return this.clientToServerMACAlgorithm; }
            set { this.clientToServerMACAlgorithm = value; }
        }
        
        /// <summary>
        /// Gets or sets the currently used MAC algorithm for packets from to the server to the
        /// client.
        /// </summary>
        public string ServerToClientMACAlgorithm
        {
            get { return this.serverToClientMACAlgorithm; }
            set { this.serverToClientMACAlgorithm = value; }
        }

        /// <summary>
        /// Gets or sets the type of the server host key (currently either "ssh-dss" or "ssh-rsa").
        /// </summary>
        public string ServerHostkeyAlgorithm
        {
            get { return this.serverHostkeyAlgorithm; }
            set { this.serverHostkeyAlgorithm = value; }
        }

        /// <summary>
        /// Gets or sets the server host key that was sent during the latest key exchange.
        /// </summary>
        [SuppressMessage("Microsoft.Performance", "CA1819:PropertiesShouldNotReturnArrays",
                        Justification = "No other way to make this work.")]
        public byte[] ServerHostkey
        {
            get { return this.serverHostkey; }
            set { this.serverHostkey = value; }
        }

        /// <summary>
        /// Gets or sets the number of kex exchanges performed on this connection so far.
        /// </summary>
        public int KeyExchangeCounter
        {
            get { return this.keyExchangeCounter; }
            set { this.keyExchangeCounter = value; }
        }
    }
}
