// <copyright file="ConnectionMonitor.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> ConnectionMonitor
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2
{
    /// <summary>
    /// A <c>ConnectionMonitor</c> is used to get notified when the
    /// underlying socket of a connection is closed.
    /// </summary>
    public interface IConnectionMonitor
    {
        /// <summary>
        /// This method is called after the connection's underlying
        /// socket has been closed. E.g., due to the {@link Connection#close()} request of the
        /// user, if the peer closed the connection, due to a fatal error during connect()
        /// (also if the socket cannot be established) or if a fatal error occured on
        /// an established connection.
        /// <para>
        /// This is an experimental feature.
        /// </para>
        /// <para>
        /// You MUST NOT make any assumption about the thread that invokes this method.
        /// </para>
        /// <para>
        /// Please note: if the connection is not connected (e.g., there was no successful
        /// connect() call), then the invocation of {@link Connection#close()} will NOT trigger
        /// this method.
        /// </para>
        /// </summary>
        /// <seealso cref="Connection.AddConnectionMonitor"></seealso>
        /// <param name="reason">The reason the connection was lost.</param>
        void ConnectionLost(Exception reason);
    }
}
