// <copyright file="CryptoWishList.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> CryptoWishList
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.Collections.ObjectModel;
using Eunomia.SSH2.Crypto.Cipher;
using Eunomia.SSH2.Crypto.Digest;
using Eunomia.SSH2.Transport;

namespace Eunomia.SSH2.Crypto
{
    /// <summary>
    /// CryptoWishList...hold the data used to coordinate which algorithms to use.
    /// </summary>
    public class CryptoWishList
    {
        private string[] kexAlgorithms;
        private string[] serverHostkeyAlgorithms;
        private string[] intc2sEncAlgos;
        private string[] ints2cEncAlgos;
        private string[] intc2sMacAlgos;
        private string[] ints2cMacAlgos;

        /// <summary>
        /// Initializes a new instance of the CryptoWishList class.
        /// </summary>
        public CryptoWishList()
        {
            this.kexAlgorithms = KexManager.DefaultKexAlgorithmList;
            this.serverHostkeyAlgorithms = KexManager.DefaultServerHostkeyAlgorithmList;
            this.C2SEncAlgos = BlockCipherFactory.GetDefaultCipherList();
            this.S2CEncAlgos = BlockCipherFactory.GetDefaultCipherList();
            this.C2SMacAlgos = MAC.GetMacList();
            this.S2CMacAlgos = MAC.GetMacList();
        }
        
        /// <summary>
        /// Gets or sets the supported key exchange alogorithms.
        /// </summary>
        public string[] KexAlgorithms
        {
            get { return this.kexAlgorithms; }
            set { this.kexAlgorithms = value; }
        }
        
        /// <summary>
        /// Gets or sets the server host key algorithms.
        /// </summary>
        public string[] ServerHostkeyAlgorithms
        {
            get { return this.serverHostkeyAlgorithms; }
            set { this.serverHostkeyAlgorithms = value; }
        }
        
        /// <summary>
        /// Gets or sets the client to server encryption algorithms.
        /// </summary>
        public string[] C2SEncAlgos
        {
            get { return this.intc2sEncAlgos; }
            set { this.intc2sEncAlgos = value; }
        }
        
        /// <summary>
        /// Gets or sets the server to client encryption algorithms.
        /// </summary>
        public string[] S2CEncAlgos
        {
            get { return this.ints2cEncAlgos; }
            set { this.ints2cEncAlgos = value; }
        }
        
        /// <summary>
        /// Gets or sets the client to server MAC algorithms.
        /// </summary>
        public string[] C2SMacAlgos
        {
            get { return this.intc2sMacAlgos; }
            set { this.intc2sMacAlgos = value; }
        }
        
        /// <summary>
        /// Gets or sets the server to client MAC algorithms.
        /// </summary>
        public string[] S2CMacAlgos
        {
            get { return this.ints2cMacAlgos; }
            set { this.ints2cMacAlgos = value; }
        }
    }
}
