﻿// <copyright file="IDigest.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> IDigest
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

namespace Eunomia.SSH2.Crypto.Digest
{
    /// <summary>
    /// IDigest interface that the Digests all inherit from.
    /// </summary>
    public interface IDigest
    {
        /// <summary>
        /// Gets the digest length in bytes.
        /// </summary>
        int DigestLength
        {
            get;
        }

        /// <summary>
        /// Update a single byte.
        /// </summary>
        /// <param name="value">The byte to update.</param>
        void Update(byte value);

        /// <summary>
        /// Update a byte array.
        /// </summary>
        /// <param name="buffer">The byte array.</param>
        void Update(byte[] buffer);

        /// <summary>
        /// Update a byte array with a starting offset and length.
        /// </summary>
        /// <param name="buffer">The  byte array.</param>
        /// <param name="offset">The starting byte in the array.</param>
        /// <param name="length">The number of bytes to process.</param>
        void Update(byte[] buffer, int offset, int length);

        /// <summary>
        /// Resets the digest.
        /// </summary>
        void Reset();
        
        /// <summary>
        /// Copies the resulting digest into a byte array.
        /// </summary>
        /// <param name="buffer">The byte array to copy the digest to.</param>
        void Digest(byte[] buffer);

        /// <summary>
        /// Copies the resulting digest into a byte array with a starting position.
        /// </summary>
        /// <param name="buffer">The byte array to copy the digest to.</param>
        /// <param name="offset">The starting position of the byte array to copy to.</param>
        void Digest(byte[] buffer, int offset);
    }
}
