// <copyright file="MD5.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> MD5
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using Org.BouncyCastle.Crypto.Digests;

namespace Eunomia.SSH2.Crypto.Digest
{
    /// <summary>
    /// MD5 class that wraps the BouncyCastle MD5Digest.
    /// </summary>
    public sealed class MD5 : IDigest
    {
        private MD5Digest digestmd5;

        /// <summary>
        /// Initializes a new instance of the MD5 class.
        /// </summary>
        public MD5()
        {
            this.digestmd5 = new MD5Digest();
            this.digestmd5.Reset();
        }

        /// <summary>
        /// Gets the digest length in bytes.
        /// </summary>
        public int DigestLength
        {
            get { return this.digestmd5.GetDigestSize(); }
        }

        /// <summary>
        /// Resets the MD5 digest.
        /// </summary>
        public void Reset()
        {
            this.digestmd5.Reset();
        }

        /// <summary>
        /// Update a single byte.
        /// </summary>
        /// <param name="value">The byte to update.</param>
        public void Update(byte value)
        {
            this.digestmd5.Update(value);
        }

        /// <summary>
        /// Update a byte array with a starting offset and length.
        /// </summary>
        /// <param name="buffer">The byte array.</param>
        /// <param name="offset">The starting byte in the array.</param>
        /// <param name="length">The number of bytes to process.</param>
        public void Update(byte[] buffer, int offset, int length)
        {
            this.digestmd5.BlockUpdate(buffer, offset, length);
        }

        /// <summary>
        /// Update a byte array.
        /// </summary>
        /// <param name="buffer">The byte array.</param>
        public void Update(byte[] buffer)
        {
            this.digestmd5.BlockUpdate(buffer, 0, buffer.Length);
        }

        /// <summary>
        /// Copies the resulting digest into a byte array with a starting position.
        /// </summary>
        /// <param name="buffer">The byte array to copy the digest to.</param>
        /// <param name="offset">The starting position of the byte array to copy to.</param>
        public void Digest(byte[] buffer, int offset)
        {
            this.digestmd5.DoFinal(buffer, offset);
        }

        /// <summary>
        /// Copies the resulting digest into a byte array.
        /// </summary>
        /// <param name="buffer">The byte array to copy the digest to.</param>
        public void Digest(byte[] buffer)
        {
            this.digestmd5.DoFinal(buffer, 0);
        }
    }
}
