// <copyright file="SHA1.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> SHA1
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using Org.BouncyCastle.Crypto.Digests;

namespace Eunomia.SSH2.Crypto.Digest
{
    /// <summary>
    /// SHA1 class that wraps the BouncyCastle Sha1Digest.
    /// </summary>
    public sealed class SHA1 : IDigest
    {
        private Sha1Digest sha1digest;

        /// <summary>
        /// Initializes a new instance of the SHA1 class.
        /// </summary>
        public SHA1()
        {
            this.sha1digest = new Sha1Digest();
            this.sha1digest.Reset();
        }

        /// <summary>
        /// Gets the digest length in bytes.
        /// </summary>
        public int DigestLength
        {
            get { return this.sha1digest.GetDigestSize(); }
        }

        /// <summary>
        /// Resets the SHA1 digest.
        /// </summary>
        public void Reset()
        {
            this.sha1digest.Reset();
        }

        /// <summary>
        /// Update a byte array.
        /// </summary>
        /// <param name="buffer">The byte array to update.</param>
        public void Update(byte[] buffer)
        {
            this.sha1digest.BlockUpdate(buffer, 0, buffer.Length);
        }

        /// <summary>
        /// Update a byte array with a starting offset and length.
        /// </summary>
        /// <param name="buffer">The  byte array.</param>
        /// <param name="offset">The starting byte in the array.</param>
        /// <param name="length">The number of bytes to process.</param>
        public void Update(byte[] buffer, int offset, int length)
        {
            this.sha1digest.BlockUpdate(buffer, offset, length);
        }

        /// <summary>
        /// Update a single byte.
        /// </summary>
        /// <param name="value">The byte to update.</param>
        public void Update(byte value)
        {
            this.sha1digest.Update(value);
        }

        /// <summary>
        /// Copies the resulting digest into a byte array.
        /// </summary>
        /// <param name="buffer">The byte array to copy the digest to.</param>
        public void Digest(byte[] buffer)
        {
            this.sha1digest.DoFinal(buffer, 0);
        }

        /// <summary>
        /// Copies the resulting digest into a byte array with a starting position.
        /// </summary>
        /// <param name="buffer">The byte array to copy the digest to.</param>
        /// <param name="offset">The starting position of the byte array to copy to.</param>
        public void Digest(byte[] buffer, int offset)
        {
            this.sha1digest.DoFinal(buffer, offset);
        }
    }
}
