// <copyright file="PacketIgnore.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketIgnore
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.IO;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketIgnore packet.
    /// </summary>
    public class PacketIgnore
    {
        private byte[] payload;
        private byte[] data;

        /// <summary>
        /// Initializes a new instance of the PacketIgnore class.
        /// </summary>
        public PacketIgnore()
        {
        }

        /// <summary>
        /// Initializes a new instance of the PacketIgnore class from an existing payload.
        /// </summary>
        /// <param name="payload">The byte array with the packet in it.</param>
        /// <param name="off">The offset to the beginning of the packet.</param>
        /// <param name="len">The length of the packet data.</param>
        public PacketIgnore(byte[] payload, int off, int len)
        {
            this.payload = new byte[len];
            Array.Copy(payload, off, this.payload, 0, len);

            TypesReader tr = new TypesReader(payload, off, len);

            int packet_type = tr.ReadByte();

            if (packet_type != Packet.SSHMessageIgnore)
            {
                throw new IOException("This is not a SSH_MSG_IGNORE packet! (" + packet_type + ")");
            }

            // Could parse string body
        }

        /// <summary>
        /// Gets or sets the data to send inside the ignore packet.
        /// </summary>
        public byte[] Data
        {
            get
            {
                return this.data;
            }

            set
            {
                this.data = value;
                this.payload = null;
            }
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageIgnore);

                    if (this.data != null)
                    {
                        tw.WriteString(this.data, 0, this.data.Length);
                    }
                    else
                    {
                        tw.WriteString(string.Empty);
                    }

                    this.payload = tw.GetBytes();
                }

                return this.payload;
            }
        }
    }
}