// <copyright file="PacketKexDhGexInit.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketKexDhGexInit
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;
using Org.BouncyCastle.Math;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketKexDHGexInit packet.
    /// This is step 1 in a newer style Diffie-Hellman exchange as described in RFC 4419.
    /// </summary>
    public class PacketKexDHGexInit
    {
        private byte[] payload;
        private BigInteger e;

        /// <summary>
        /// Initializes a new instance of the PacketKexDHGexInit class.
        /// </summary>
        /// <param name="e">This is the client's 'public' key.</param>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "e", Justification = "Consistancy to ganymed project.")]
        public PacketKexDHGexInit(BigInteger e)
        {
            this.e = e;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// This is normally set to the value of e = this.g.ModPow(this.x, this.p) where
        /// g is the 'generator', x is the secret integer and p is the 'large prime'.
        /// This sometimes is refered to as the client's public key in DhExchange.cs.
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageKEXDHGEXInitialize);
                    tw.WriteMPInt(this.e);
                    this.payload = tw.GetBytes();
                }
    
                return this.payload;
            }
        }
    }
}
