// <copyright file="PacketKexDhGexRequest.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketKexDhGexRequest
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketKexDHGexRequest packet.
    /// Packet used to start newer style key exchange described in RFC 4419.
    /// </summary>
    public class PacketKexDHGexRequest
    {
        private byte[] payload;

        private int min;
        private int n;
        private int max;

        /// <summary>
        /// Initializes a new instance of the PacketKexDHGexRequest class.
        /// </summary>
        /// <param name="para">The Diffie-Hellman key exchange parameters.</param>
        public PacketKexDHGexRequest(DHGexParameters para)
        {
            this.min = para.MinGroupLength;
            this.n = para.PreferredGroupLength;
            this.max = para.MaxGroupLength;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageKEXDHGEXRequest);
                    tw.WriteUINT32((uint)this.min);
                    tw.WriteUINT32((uint)this.n);
                    tw.WriteUINT32((uint)this.max);
                    this.payload = tw.GetBytes();
                }
    
                return this.payload;
            }
        }
    }
}
