// <copyright file="PacketKexDhGexRequestOld.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketKexDhGexRequestOld
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketKexDHGexRequestOld packet.
    /// Packet used to start newer style key exchange described in RFC 4419.
    /// </summary>
    public class PacketKexDHGexRequestOld
    {
        private byte[] payload;

        private int n;

        /// <summary>
        /// Initializes a new instance of the PacketKexDHGexRequestOld class.
        /// </summary>
        /// <param name="para">The Diffie-Hellman key exchange parameters.</param>
        public PacketKexDHGexRequestOld(DHGexParameters para)
        {
            this.n = para.PreferredGroupLength;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageKEXDHGEXRequestOld);
                    tw.WriteUINT32((uint)this.n);
                    this.payload = tw.GetBytes();
                }
    
                return this.payload;
            }
        }
    }
}
