// <copyright file="PacketOpenDirectTCPIPChannel.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketOpenDirectTCPIPChannel
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketOpenDirectTCPIPChannel packet.
    /// </summary>
    public class PacketOpenDirectTCPIPChannel
    {
        private byte[] payload;

        private int channelID;
        private int initialWindowSize;
        private int maxPacketSize;

        private string hostToConnect;
        private int portToConnect;
        private string originator_IP_address;
        private int originator_port;

        /// <summary>
        /// Initializes a new instance of the PacketOpenDirectTCPIPChannel class.
        /// </summary>
        /// <param name="channelId">The channel id.</param>
        /// <param name="initialWindowSize">The initial window size.</param>
        /// <param name="maxPacketSize">The maximum packet size.</param>
        /// <param name="hostToConnect">The host to connect to.</param>
        /// <param name="portToConnect">The port to connect to.</param>
        /// <param name="originatorIPAddress">The IP address of the originator.</param>
        /// <param name="originatorPort">The port of the originator.</param>
        public PacketOpenDirectTCPIPChannel(
            int channelId,
            int initialWindowSize,
            int maxPacketSize,
            string hostToConnect,
            int portToConnect,
            string originatorIPAddress,
            int originatorPort)
        {
            this.channelID = channelId;
            this.initialWindowSize = initialWindowSize;
            this.maxPacketSize = maxPacketSize;
            this.hostToConnect = hostToConnect;
            this.portToConnect = portToConnect;
            this.originator_IP_address = originatorIPAddress;
            this.originator_port = originatorPort;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();

                    tw.WriteByte(Packet.SSHMessageChannelOpen);
                    tw.WriteString("direct-tcpip");
                    tw.WriteUINT32((uint)this.channelID);
                    tw.WriteUINT32((uint)this.initialWindowSize);
                    tw.WriteUINT32((uint)this.maxPacketSize);
                    tw.WriteString(this.hostToConnect);
                    tw.WriteUINT32((uint)this.portToConnect);
                    tw.WriteString(this.originator_IP_address);
                    tw.WriteUINT32((uint)this.originator_port);

                    this.payload = tw.GetBytes();
                }

                return this.payload;
            }
        }
    }
}
