// <copyright file="PacketServiceAccept.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketServiceAccept
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.IO;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketServiceAccept packet.
    /// </summary>
    public class PacketServiceAccept
    {
        private byte[] payload;

        private string serviceName;

        /// <summary>
        /// Initializes a new instance of the PacketServiceAccept class.
        /// </summary>
        /// <param name="serviceName">The service name that is accepted.</param>
        public PacketServiceAccept(string serviceName)
        {
            this.serviceName = serviceName;
        }

        /// <summary>
        /// Initializes a new instance of the PacketServiceAccept class from an existing payload.
        /// </summary>
        /// <param name="payload">The byte array with the packet in it.</param>
        /// <param name="off">The offset to the beginning of the packet.</param>
        /// <param name="len">The length of the packet data.</param>
        public PacketServiceAccept(byte[] payload, int off, int len)
        {
            this.payload = new byte[len];
            Array.Copy(payload, off, this.payload, 0, len);

            TypesReader tr = new TypesReader(payload, off, len);

            int packet_type = tr.ReadByte();

            if (packet_type != Packet.SSHMessageServiceAccept)
            {
                throw new IOException("This is not a SSH_MSG_SERVICE_ACCEPT! ("
                                      + packet_type + ")");
            }
            
            this.serviceName = string.Empty;

            if (tr.Remain != 0)
            {
                this.serviceName = tr.ReadString();
            }
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageServiceAccept);
                    tw.WriteString(this.serviceName);
                    this.payload = tw.GetBytes();
                }
                
                return this.payload;
            }
        }
    }
}
