// <copyright file="PacketSessionExecCommand.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketSessionExecCommand
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketSessionExecCommand packet.
    /// </summary>
    public class PacketSessionExecCommand
    {
        private byte[] payload;

        private int recipientChannelId;
        private bool wantReply;
        private string command;

        /// <summary>
        /// Initializes a new instance of the PacketSessionExecCommand class.
        /// </summary>
        /// <param name="recipientChannelId">The receipient channel id.</param>
        /// <param name="wantReply">Whether a reply is wanted.</param>
        /// <param name="command">The command to execute.</param>
        public PacketSessionExecCommand(int recipientChannelId, bool wantReply, string command)
        {
            this.recipientChannelId = recipientChannelId;
            this.wantReply = wantReply;
            this.command = command;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageChannelRequest);
                    tw.WriteUINT32((uint)this.recipientChannelId);
                    tw.WriteString("exec");
                    tw.WriteBoolean(this.wantReply);
                    tw.WriteString(this.command);
                    this.payload = tw.GetBytes();
                }

                return this.payload;
            }
        }
    }
}
