// <copyright file="PacketSessionPtyRequest.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketSessionPtyRequest
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketSessionPtyRequest packet.
    /// </summary>
    public class PacketSessionPtyRequest
    {
        private byte[] payload;

        private int recipientChannelID;
        private bool wantReply;
        private string term;
        private int character_width;
        private int character_height;
        private int pixel_width;
        private int pixel_height;
        private byte[] terminalModes;

        /// <summary>
        /// Initializes a new instance of the PacketSessionPtyRequest class.
        /// </summary>
        /// <param name="recipientChannelId">The receipient channel id.</param>
        /// <param name="wantReply">Whether a reply is wanted.</param>
        /// <param name="term">The terminal type (a string).</param>
        /// <param name="characterWidth">The width of the terminal in characters.</param>
        /// <param name="characterHeight">The height of the terminal in characters.</param>
        /// <param name="pixelWidth">The width of the terminal in pixels.</param>
        /// <param name="pixelHeight">The height of the terminal in pixels.</param>
        /// <param name="terminalModes">The terminal modes (byet array).</param>
        public PacketSessionPtyRequest(
            int recipientChannelId,
            bool wantReply,
            string term,
            int characterWidth,
            int characterHeight,
            int pixelWidth,
            int pixelHeight,
            byte[] terminalModes)
        {
            this.recipientChannelID = recipientChannelId;
            this.wantReply = wantReply;
            this.term = term;
            this.character_width = characterWidth;
            this.character_height = characterHeight;
            this.pixel_width = pixelWidth;
            this.pixel_height = pixelHeight;
            this.terminalModes = terminalModes;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageChannelRequest);
                    tw.WriteUINT32((uint)this.recipientChannelID);
                    tw.WriteString("pty-req");
                    tw.WriteBoolean(this.wantReply);
                    tw.WriteString(this.term);
                    tw.WriteUINT32((uint)this.character_width);
                    tw.WriteUINT32((uint)this.character_height);
                    tw.WriteUINT32((uint)this.pixel_width);
                    tw.WriteUINT32((uint)this.pixel_height);
                    tw.WriteString(this.terminalModes, 0, this.terminalModes.Length);

                    this.payload = tw.GetBytes();
                }

                return this.payload;
            }
        }
    }
}
