// <copyright file="PacketSessionSubsystemRequest.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketSessionSubsystemRequest
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketSessionSubsystemRequest packet.
    /// </summary>
    public class PacketSessionSubsystemRequest
    {
        private byte[] payload;

        private int recipientChannelId;
        private bool wantReply;
        private string subsystem;

        /// <summary>
        /// Initializes a new instance of the PacketSessionSubsystemRequest class.
        /// </summary>
        /// <param name="recipientChannelId">The receipient channel id.</param>
        /// <param name="wantReply">Whether a reply is wanted.</param>
        /// <param name="subsystem">The desired subsystem.</param>
        public PacketSessionSubsystemRequest(int recipientChannelId, bool wantReply, string subsystem)
        {
            this.recipientChannelId = recipientChannelId;
            this.wantReply = wantReply;
            this.subsystem = subsystem;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageChannelRequest);
                    tw.WriteUINT32((uint)this.recipientChannelId);
                    tw.WriteString("subsystem");
                    tw.WriteBoolean(this.wantReply);
                    tw.WriteString(this.subsystem);
                    this.payload = tw.GetBytes();
                    tw.GetBytes(this.payload);
                }

                return this.payload;
            }
        }
    }
}
