// <copyright file="PacketUserauthBanner.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketUserauthBanner
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.IO;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketUserauthBanner packet.
    /// </summary>
    public class PacketUserauthBanner
    {
        private byte[] payload;

        private string message;
        private string language;

        /// <summary>
        /// Initializes a new instance of the PacketUserauthBanner class.
        /// </summary>
        /// <param name="message">The banner message.</param>
        /// <param name="language">The language the message is in.</param>
        public PacketUserauthBanner(string message, string language)
        {
            this.message = message;
            this.language = language;
        }

        /// <summary>
        /// Initializes a new instance of the PacketUserauthBanner class from an existing payload.
        /// </summary>
        /// <param name="payload">The byte array with the packet in it.</param>
        /// <param name="off">The offset to the beginning of the packet.</param>
        /// <param name="len">The length of the packet data.</param>
        public PacketUserauthBanner(byte[] payload, int off, int len)
        {
            this.payload = new byte[len];
            Array.Copy(payload, off, this.payload, 0, len);

            TypesReader tr = new TypesReader(payload, off, len);

            int packet_type = tr.ReadByte();

            if (packet_type != Packet.SSHMessageUserAuthorizationBanner)
            {
                throw new IOException("This is not a SSH_MSG_USERAUTH_BANNER! (" + packet_type + ")");
            }

            this.message = tr.ReadString("UTF-8");
            this.language = tr.ReadString();

            if (tr.Remain != 0)
            {
                throw new IOException("Padding in SSH_MSG_USERAUTH_REQUEST packet!");
            }
        }

        /// <summary>
        /// Gets the banner text.
        /// </summary>
        public string Banner
        {
            get { return this.message; }
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageUserAuthorizationBanner);
                    tw.WriteString(this.message);
                    tw.WriteString(this.language);
                    this.payload = tw.GetBytes();
                }
                
                return this.payload;
            }
        }
    }
}
