// <copyright file="PacketUserauthInfoResponse.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketUserauthInfoResponse
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketUserauthInfoResponse packet.
    /// </summary>
    public class PacketUserauthInfoResponse
    {
        private byte[] payload;

        private string[] responses;

        /// <summary>
        /// Initializes a new instance of the PacketUserauthInfoResponse class.
        /// </summary>
        /// <param name="responses">The responses to the server prompts in a string array.</param>
        public PacketUserauthInfoResponse(string[] responses)
        {
            this.responses = responses;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageUserAuthorizationInfoRequest);
                    tw.WriteUINT32((uint)this.responses.Length);
                    for (int i = 0; i < this.responses.Length; i++)
                    {
                        tw.WriteString(this.responses[i]);
                    }

                    this.payload = tw.GetBytes();
                }

                return this.payload;
            }
        }
    }
}
