// <copyright file="PacketUserauthRequestInteractive.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> PacketUserauthRequestInteractive
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2.Packets
{
    /// <summary>
    /// Handles a PacketUserauthRequestInteractive packet.
    /// </summary>
    public class PacketUserauthRequestInteractive
    {
        private byte[] payload;

        private string userName;
        private string serviceName;
        private string[] submethods;

        /// <summary>
        /// Initializes a new instance of the PacketUserauthRequestInteractive class.
        /// </summary>
        /// <param name="serviceName">The service name to start after authentication.</param>
        /// <param name="user">The user name in UTF-8.</param>
        /// <param name="subMethods">An array of submethods (publickey, password, hostbased, none, etc).</param>
        public PacketUserauthRequestInteractive(string serviceName, string user, string[] subMethods)
        {
            this.serviceName = serviceName;
            this.userName = user;
            this.submethods = subMethods;
        }

        /// <summary>
        /// Gets the payload of the packet (creates if required).
        /// </summary>
        public byte[] Payload
        {
            get
            {
                if (this.payload == null)
                {
                    TypesWriter tw = new TypesWriter();
                    tw.WriteByte(Packet.SSHMessageUserAuthorizationRequest);
                    tw.WriteString(this.userName);
                    tw.WriteString(this.serviceName);
                    tw.WriteString("keyboard-interactive");
                    tw.WriteString(string.Empty); // draft-ietf-secsh-newmodes-04.txt says that
                    // the language tag should be empty.
                    tw.WriteNameList(this.submethods);

                    this.payload = tw.GetBytes();
                }

                return this.payload;
            }
        }
    }
}
