// <copyright file="SFTPException.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> SFTPException
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;
using System.IO;
using Eunomia.SSH2.SFTP;

namespace Eunomia.SSH2
{
    /// <summary>
    /// Used in combination with the SFTPv3Client. This exception wraps
    /// error messages sent by the SFTP server.
    /// </summary>
    //// TODO: Implement the other required methods.
    [Serializable]
    [SuppressMessage("Microsoft.Design", "CA1032:ImplementStandardExceptionConstructors",
                    Justification = "TODO: Implement the other required methods.")]
    public class SFTPException : IOException
    {
        /// <summary>
        /// Initializes a new instance of the SFTPException class.
        /// </summary>
        /// <param name="msg">The exception text message.</param>
        /// <param name="errorCode">The exception error code.</param>
        internal SFTPException(string msg, int errorCode)
        {
            string[] detail = ErrorCodes.GetDescription(errorCode);
            if (detail == null)
            {
                msg = msg + " (UNKNOWN SFTP ERROR CODE)";
            }
            else
            {
                msg = msg + " (" + detail[0] + ": " + detail[1] + ")";
            }
        }
    }
}
