﻿// <copyright file="SFTPv3DirectoryEntry.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> SFTPv3DirectoryEntry
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2
{
    /// <summary>
    /// A SFTPv3DirectoryEntry as returned by SFTPv3Client.
    /// </summary>
    public class SFTPv3DirectoryEntry
    {
        private string filename;
        private string longEntry;
        private SFTPv3FileAttributes attributes;

        /// <summary>
        /// Gets or sets a relative name within the directory, without any path components.
        /// </summary>
        public string FileName
        {
            get { return this.filename; }
            set { this.filename = value; }
        }
        
        /// <summary>
        /// Gets or sets an expanded format for the file name, similar to what is returned by
        /// "ls -l" on Un*x systems.
        /// <para>
        /// The format of this field is unspecified by the SFTP v3 protocol.
        /// It MUST be suitable for use in the output of a directory listing
        /// command (in fact, the recommended operation for a directory listing
        /// command is to simply display this data).  However, clients SHOULD NOT
        /// attempt to parse the longname field for file attributes; they SHOULD
        /// use the attrs field instead.
        /// </para>
        /// <para>
        /// The recommended format for the longname field is as follows:
        /// -rwxr-xr-x   1 mjos     staff      348911 Mar 25 14:29 t-filexfer.
        /// </para>
        /// </summary>
        public string LongEntry
        {
            get { return this.longEntry; }
            set { this.longEntry = value; }
        }
        
        /// <summary>
        /// Gets or sets the attributes of this entry.
        /// </summary>
        public SFTPv3FileAttributes Attributes
        {
            get { return this.attributes; }
            set { this.attributes = value; }
        }
    }
}
