﻿// <copyright file="AttribTypes.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> AttribTypes
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;

namespace Eunomia.SSH2.SFTP
{
    /// <summary>
    /// Types for the 'type' field in the SFTP ATTRS data type.
    /// </summary>
    /// <remarks>
    /// On a POSIX system, these values would be derived from the mode field
    /// of the stat structure.  SPECIAL should be used for files that are of
    /// a known type which cannot be expressed in the protocol. UNKNOWN
    /// should be used if the type is not known.
    /// </remarks>
    [SuppressMessage("Microsoft.Performance", "CA1815:OverrideEqualsAndOperatorEqualsOnValueTypes",
                    Justification = "We will never compare or sort instances of this struct.")]
    public struct AttribTypes
    {
        /// <summary> Value for a Regular file. </summary>
        public const int SSHFileTransferTypeRegular = 1;

        /// <summary> Value for a Directory. </summary>
        public const int SSHFileTransferTypeDirectory = 2;

        /// <summary> Value for a Symlink. </summary>
        public const int SSHFileTransferTypeSymbolicLink = 3;

        /// <summary> Value for a Special file. </summary>
        public const int SSHFileTransferTypeSpecial = 4;

        /// <summary> Value for a Unkown file. </summary>
        public const int SSHFileTransferTypeUnknown = 5;

        /// <summary> Value for a Socket. </summary>
        public const int SSHFileTransferTypeSocket = 6;

        /// <summary> Value for a Character Device. </summary>
        public const int SSHFileTransferTypeCharacterDevice = 7;

        /// <summary> Value for a Block Device. </summary>
        public const int SSHFileTransferTypeBlockDevice = 8;

        /// <summary> Value for a FIFO. </summary>
        public const int SSHFileTransferTypeFIFO = 9;
    }
}
