﻿// <copyright file="ErrorCodes.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> ErrorCodes
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2.SFTP
{
    #pragma warning disable 1591
    /// <summary>
    /// SFTP Error Codes.
    /// </summary>
    public static class ErrorCodes
    {
        public const int SSHFileTransferOk = 0;
        public const int SSHFileTransferEOF = 1;
        public const int SSHFileTransferNoSuchFile = 2;
        public const int SSHFileTransferPermissionDenied = 3;
        public const int SSHFileTransferFailure = 4;
        public const int SSHFileTransferBadMessage = 5;
        public const int SSHFileTransferNoConnection = 6;
        public const int SSHFileTransferConnectionLost = 7;
        public const int SSHFileTransferOperationUnsupported = 8;
        public const int SSHFileTransferInvalidHandle = 9;
        public const int SSHFileTransferNoSuchPath = 10;
        public const int SSHFileTransferFileAlreadyExists = 11;
        public const int SSHFileTransferWriteProtect = 12;
        public const int SSHFileTransferNoMedia = 13;
        public const int SSHFileTransferNoSpaceOnFileSystem = 14;
        public const int SSHFileTransferQuotaExceeded = 15;
        public const int SSHFileTransferUnknownPrinciple = 16;
        public const int SSHFileTransferLockConflict = 17;
        public const int SSHFileTransferDirectoryNotEmpty = 18;
        public const int SSHFileTransferNotADirectory = 19;
        public const int SSHFileTransferInvalidFileName = 20;
        public const int SSHFileTransferLinkLoop = 21;
        public const int SSHFileTransferCannotDelete = 22;
        public const int SSHFileTransferInvalidParameter = 23;
        public const int SSHFileTransferFileIsADirectory = 24;
        public const int SSHFileTransferByteRangeLockConflict = 25;
        public const int SSHFileTransferByteRangeLockRefused = 26;
        public const int SSHFileTransferDeletePending = 27;
        public const int SSHFileTransferFileCorrupt = 28;
        public const int SSHFileTransferOwnerInvalid = 29;
        public const int SSHFileTransferGroupInvalid = 30;
        public const int SSHFileTransferNoMatchingByteRangeLock = 31;

        private static readonly string[][] messages =
        {
            new string[]
            {
                "SSH_FX_OK",
                "Indicates successful completion of the operation."
            },
            new string[]
            {
                "SSH_FX_EOF",
                "An attempt to read past the end-of-file was made; or, there are no more directory entries to return."
            },
            new string[]
            {
                "SSH_FX_NO_SUCH_FILE",
                "A reference was made to a file which does not exist."
            },
            new string[]
            { 
                "SSH_FX_PERMISSION_DENIED",
                "The user does not have sufficient permissions to perform the operation."
            },
            new string[]
            {
                "SSH_FX_FAILURE",
                "An error occurred, but no specific error code exists to describe the failure."
            },
            new string[]
            {
                "SSH_FX_BAD_MESSAGE",
                "A badly formatted packet or other SFTP protocol incompatibility was detected."
            },
            new string[]
            {
                "SSH_FX_NO_CONNECTION",
                "There is no connection to the server."
            },
            new string[]
            {
                "SSH_FX_CONNECTION_LOST",
                "The connection to the server was lost."
            },
            new string[]
            {
                "SSH_FX_OP_UNSUPPORTED",
                "An attempted operation could not be completed by the server because the server does not support the operation."
            },
            new string[]
            {
                "SSH_FX_INVALID_HANDLE",
                "The handle value was invalid."
            },
            new string[]
            {
                "SSH_FX_NO_SUCH_PATH",
                "The file path does not exist or is invalid."
            },
            new string[]
            {
                "SSH_FX_FILE_ALREADY_EXISTS",
                "The file already exists."
            },
            new string[]
            {
                "SSH_FX_WRITE_PROTECT",
                "The file is on read-only media, or the media is write protected."
            },
            new string[]
            {
                "SSH_FX_NO_MEDIA",
                "The requested operation cannot be completed because there is no media available in the drive."
            },
            new string[]
            {
                "SSH_FX_NO_SPACE_ON_FILESYSTEM",
                "The requested operation cannot be completed because there is insufficient free space on the filesystem."
            },
            new string[]
            {
                "SSH_FX_QUOTA_EXCEEDED",
                "The operation cannot be completed because it would exceed the user's storage quota."
            },
            new string[]
            {
                "SSH_FX_UNKNOWN_PRINCIPAL",
                "A principal referenced by the request (either the 'owner', 'group', or 'who' field of an ACL), was unknown. The error specific data contains the problematic names."
            },
            new string[]
            {
                "SSH_FX_LOCK_CONFLICT",
                "The file could not be opened because it is locked by another process."
            },
            new string[]
            {
                "SSH_FX_DIR_NOT_EMPTY",
                "The directory is not empty." 
            },
            new string[]
            {
                "SSH_FX_NOT_A_DIRECTORY",
                "The specified file is not a directory."
            },
            new string[]
            {
                "SSH_FX_INVALID_FILENAME",
                "The filename is not valid."
            },
            new string[]
            {
                "SSH_FX_LINK_LOOP",
                "Too many symbolic links encountered or, an SSH_FXF_NOFOLLOW open encountered a symbolic link as the component." 
            },
            new string[]
            {
                "SSH_FX_CANNOT_DELETE",
                "The file cannot be deleted. One possible reason is that the advisory READONLY attribute-bit is set."
            },
            new string[]
            {
                "SSH_FX_INVALID_PARAMETER",
                "One of the parameters was out of range, or the parameters specified cannot be used together."
            },
            new string[]
            {
                "SSH_FX_FILE_IS_A_DIRECTORY",
                "The specified file was a directory in a context where a directory cannot be used."
            },
            new string[]
            {
                "SSH_FX_BYTE_RANGE_LOCK_CONFLICT",
                " A read or write operation failed because another process's mandatory byte-range lock overlaps with the request."
            },
            new string[]
            {
                "SSH_FX_BYTE_RANGE_LOCK_REFUSED",
                "A request for a byte range lock was refused."
            },
            new string[]
            {
                "SSH_FX_DELETE_PENDING",
                "An operation was attempted on a file for which a delete operation is pending."
            },
            new string[]
            {
                "SSH_FX_FILE_CORRUPT",
                "The file is corrupt; an filesystem integrity check should be run."
            },
            new string[]
            {
                "SSH_FX_OWNER_INVALID",
                "The principal specified can not be assigned as an owner of a file."
            },
            new string[]
            {
                "SSH_FX_GROUP_INVALID",
                "The principal specified can not be assigned as the primary group of a file."
            },
            new string[]
            {
                "SSH_FX_NO_MATCHING_BYTE_RANGE_LOCK",
                "The requested operation could not be completed because the	specifed byte range lock has not been granted."
            }
        };

        /// <summary>
        /// Static method that gets an error name and description when passed the error code.
        /// </summary>
        /// <param name="errorCode">The error code.</param>
        /// <returns>The an error 'name' and description.</returns>
        public static string[] GetDescription(int errorCode)
        {
            if ((errorCode < 0) || (errorCode >= messages.Length))
            {
                return null;
            }

            return messages[errorCode];
        }
    #pragma warning restore 1591
    }
}
