// <copyright file="DSAPrivateKey.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> DSAPrivateKey
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;

using Org.BouncyCastle.Math;

namespace Eunomia.SSH2.Signature
{
    /// <summary>
    /// DSAPrivateKey.  Stores information about a DSA private key.
    /// </summary>
    public class DSAPrivateKey
    {
        private BigInteger p;
        private BigInteger q;
        private BigInteger g;
        private BigInteger x;
        private BigInteger y;

        /// <summary>
        /// Initializes a new instance of the DSAPrivateKey class.
        /// </summary>
        /// <param name="p">The p parameter.</param>
        /// <param name="q">The q parameter.</param>
        /// <param name="g">The g parameter.</param>
        /// <param name="y">The y parameter.</param>
        /// <param name="x">The x parameter.</param>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "p", Justification = "Consistancy to ganymed project.")]
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "q", Justification = "Consistancy to ganymed project.")]
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "g", Justification = "Consistancy to ganymed project.")]
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "y", Justification = "Consistancy to ganymed project.")]
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "x", Justification = "Consistancy to ganymed project.")]
        public DSAPrivateKey(
            BigInteger p,
            BigInteger q,
            BigInteger g,
            BigInteger y,
            BigInteger x)
        {
            this.p = p;
            this.q = q;
            this.g = g;
            this.y = y;
            this.x = x;
        }
        
        /// <summary>
        /// Gets the P parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "P", Justification = "Consistancy to ganymed project.")]
        public BigInteger P
        {
            get { return this.p; }
        }
        
        /// <summary>
        /// Gets the Q parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "Q", Justification = "Consistancy to ganymed project.")]
        public BigInteger Q
        {
            get { return this.q; }
        }
        
        /// <summary>
        /// Gets the G parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "G", Justification = "Consistancy to ganymed project.")]
        public BigInteger G
        {
            get { return this.g; }
        }
        
        /// <summary>
        /// Gets the X parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "X", Justification = "Consistancy to ganymed project.")]
        public BigInteger X
        {
            get { return this.x; }
        }
        
        /// <summary>
        /// Gets the Y parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "Y", Justification = "Consistancy to ganymed project.")]
        public BigInteger Y
        {
            get { return this.y; }
        }

        /// <summary>
        /// Gets the public key for this private key.
        /// </summary>
        public DSAPublicKey PublicKey
        {
            get { return new DSAPublicKey(this.p, this.q, this.g, this.y); }
        }
    }
}
