// <copyright file="DSAPublicKey.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> DSAPublicKey
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;

using Org.BouncyCastle.Math;

namespace Eunomia.SSH2.Signature
{
    /// <summary>
    /// DSAPublicKey.  Stores information about a DSA public key.
    /// </summary>
    public class DSAPublicKey
    {
        private BigInteger p;
        private BigInteger q;
        private BigInteger g;
        private BigInteger y;

        /// <summary>
        /// Initializes a new instance of the DSAPublicKey class.
        /// </summary>
        /// <param name="p">The p parameter.</param>
        /// <param name="q">The q parameter.</param>
        /// <param name="g">The g parameter.</param>
        /// <param name="y">The y parameter.</param>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "p", Justification = "Consistancy to ganymed project.")]
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "q", Justification = "Consistancy to ganymed project.")]
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "g", Justification = "Consistancy to ganymed project.")]
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "y", Justification = "Consistancy to ganymed project.")]
        public DSAPublicKey(BigInteger p, BigInteger q, BigInteger g, BigInteger y)
        {
            this.p = p;
            this.q = q;
            this.g = g;
            this.y = y;
        }
        
        /// <summary>
        /// Gets the P parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "P", Justification = "Consistancy to ganymed project.")]
        public BigInteger P
        {
            get { return this.p; }
        }
        
        /// <summary>
        /// Gets the Q parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "Q", Justification = "Consistancy to ganymed project.")]
        public BigInteger Q
        {
            get { return this.q; }
        }
        
        /// <summary>
        /// Gets the G parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "G", Justification = "Consistancy to ganymed project.")]
        public BigInteger G
        {
            get { return this.g; }
        }
        
        /// <summary>
        /// Gets the Y parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "Y", Justification = "Consistancy to ganymed project.")]
        public BigInteger Y
        {
            get { return this.y; }
        }
    }
}
