// <copyright file="RSAPrivateKey.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> RSAPrivateKey
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;

using Org.BouncyCastle.Math;

namespace Eunomia.SSH2.Signature
{
    /// <summary>
    /// RSAPrivateKey.  Stores information about a RSA private key.
    /// </summary>
    public class RSAPrivateKey
    {
        private BigInteger d;
        private BigInteger e;
        private BigInteger n;

        /// <summary>
        /// Initializes a new instance of the RSAPrivateKey class.
        /// </summary>
        /// <param name="d">The d parameter.</param>
        /// <param name="e">The e parameter.</param>
        /// <param name="n">The n parameter.</param>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "d", Justification = "Consistancy to ganymed project.")]
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "e", Justification = "Consistancy to ganymed project.")]
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "n", Justification = "Consistancy to ganymed project.")]
        public RSAPrivateKey(BigInteger d, BigInteger e, BigInteger n)
        {
            this.d = d;
            this.e = e;
            this.n = n;
        }
        
        /// <summary>
        /// Gets the D parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "D", Justification = "Consistancy to ganymed project.")]
        public BigInteger D
        {
            get { return this.d; }
        }
        
        /// <summary>
        /// Gets the E parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "E", Justification = "Consistancy to ganymed project.")]
        public BigInteger E
        {
            get { return this.e; }
        }
        
        /// <summary>
        /// Gets the N parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "N", Justification = "Consistancy to ganymed project.")]
        public BigInteger N
        {
            get { return this.n; }
        }

        /// <summary>
        /// Gets the public key for this private key.
        /// </summary>
        public RSAPublicKey PublicKey
        {
            get { return new RSAPublicKey(this.e, this.n); }
        }
    }
}
