// <copyright file="RSAPublicKey.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> RSAPublicKey
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;
using System.Diagnostics.CodeAnalysis;

using Org.BouncyCastle.Math;

namespace Eunomia.SSH2.Signature
{
    /// <summary>
    /// RSAPublicKey.  Stores information about a RSA public key.
    /// </summary>
    public class RSAPublicKey
    {
        private BigInteger e;
        private BigInteger n;

        /// <summary>
        /// Initializes a new instance of the RSAPublicKey class.
        /// </summary>
        /// <param name="e">The e parameter.</param>
        /// <param name="n">The n parameter.</param>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "e", Justification = "Consistancy to ganymed project.")]
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "n", Justification = "Consistancy to ganymed project.")]
        public RSAPublicKey(BigInteger e, BigInteger n)
        {
            this.e = e;
            this.n = n;
        }
        
        /// <summary>
        /// Gets the E parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "E", Justification = "Consistancy to ganymed project.")]
        public BigInteger E
        {
            get { return this.e; }
        }
        
        /// <summary>
        /// Gets the N parameter.
        /// </summary>
        [SuppressMessage("Microsoft.Naming", "CA1704:IdentifiersShouldBeSpelledCorrectly", MessageId = "N", Justification = "Consistancy to ganymed project.")]
        public BigInteger N 
        {
            get { return this.n; }
        }
    }
}
