﻿// <copyright file="KexParameters.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> KexParameters
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2.Transport
{
    /// <summary>
    /// Class to store key exchange parameters.
    /// </summary>
    public class KexParameters
    {
        private byte[] cookie;
        private string[] kexAlgorithms;
        private string[] serverHostkeyAlgorithms;
        private string[] encryptionAlgorithmsClientToServer;
        private string[] encryptionAlgorithmsServerToClient;
        private string[] macAlgorithmsClientToServer;
        private string[] macAlgorithmsServerToClient;
        private string[] compressionAlgorithmsClientToServer;
        private string[] compressionAlgorithmsServerToClient;
        private string[] languagesClientToServer;
        private string[] languagesServerToClient;
        private bool firstKexPacketFollows;
        private int reservedField1;
        
        /// <summary>
        /// Gets or sets a randomly generated 'cookie' to track this key exchange.
        /// </summary>
        public byte[] Cookie
        {
            get { return this.cookie; }
            set { this.cookie = value; }
        }
        
        /// <summary>
        /// Gets or sets the supported key exchange alogorithms.
        /// </summary>
        public string[] KexAlgorithms
        {
            get { return this.kexAlgorithms; }
            set { this.kexAlgorithms = value; }
        }
        
        /// <summary>
        /// Gets or sets the server host key algorithms.
        /// </summary>
        public string[] ServerHostkeyAlgorithms
        {
            get { return this.serverHostkeyAlgorithms; }
            set { this.serverHostkeyAlgorithms = value; }
        }
        
        /// <summary>
        /// Gets or sets the encryption algorithms from client to server.
        /// </summary>
        public string[] EncryptionAlgorithmsClientToServer
        {
            get { return this.encryptionAlgorithmsClientToServer; }
            set { this.encryptionAlgorithmsClientToServer = value; }
        }
        
        /// <summary>
        /// Gets or sets the encryption algorithms from server to client.
        /// </summary>
        public string[] EncryptionAlgorithmsServerToClient
        {
            get { return this.encryptionAlgorithmsServerToClient; }
            set { this.encryptionAlgorithmsServerToClient = value; }
        }
        
        /// <summary>
        /// Gets or sets the MAC algorithms from client to server.
        /// </summary>
        public string[] MacAlgorithmsClientToServer
        {
            get { return this.macAlgorithmsClientToServer; }
            set { this.macAlgorithmsClientToServer = value; }
        }
        
        /// <summary>
        /// Gets or sets the MAC algorithms from server to client.
        /// </summary>
        public string[] MacAlgorithmsServerToClient
        {
            get { return this.macAlgorithmsServerToClient; }
            set { this.macAlgorithmsServerToClient = value; }
        }
        
        /// <summary>
        /// Gets or sets the compression algorithms from client to server.
        /// </summary>
        public string[] CompressionAlgorithmsClientToServer
        {
            get { return this.compressionAlgorithmsClientToServer; }
            set { this.compressionAlgorithmsClientToServer = value; }
        }
        
        /// <summary>
        /// Gets or sets the compression algorithms from server to client.
        /// </summary>
        public string[] CompressionAlgorithmsServerToClient
        {
            get { return this.compressionAlgorithmsServerToClient; }
            set { this.compressionAlgorithmsServerToClient = value; }
        }
        
        /// <summary>
        /// Gets or sets the available languages from client to server.
        /// </summary>
        public string[] LanguagesClientToServer
        {
            get { return this.languagesClientToServer; }
            set { this.languagesClientToServer = value; }
        }
        
        /// <summary>
        /// Gets or sets the available languages from server to client.
        /// </summary>
        public string[] LanguagesServerToClient
        {
            get { return this.languagesServerToClient; }
            set { this.languagesServerToClient = value; }
        }
        
        /// <summary>
        /// Gets or sets a value indicating whether the first kex packet will follow.
        /// </summary>
        public bool FirstKexPacketFollows
        {
            get { return this.firstKexPacketFollows; }
            set { this.firstKexPacketFollows = value; }
        }
        
        /// <summary>
        /// Gets or sets the reserved field 1...how excitnig.
        /// </summary>
        public int ReservedField1
        {
            get { return this.reservedField1; }
            set { this.reservedField1 = value; }
        }
    }
}
