﻿// <copyright file="NegotiatedParameters.cs" company="David Lawler">
//     David Lawler, Copyright (c) 2010 David Lawler. All rights reserved.
// </copyright>
// <summary> NegotiatedParameters
// </summary>
// <author>  David Lawler, translated from Christian Plattner's ganymed 2.51 beta 1
// </author>
// <version> 0.6.0, 12/24/2010
// </version>

using System;

namespace Eunomia.SSH2.Transport
{
    /// <summary>
    /// The paramters that were agreed upon.
    /// </summary>
    public class NegotiatedParameters
    {
        private bool negotiateSuccessful;
        private bool guessOk;
        private string kexAlgo;
        private string serverHostkeyAlgo;
        private string encAlgoClientToServer;
        private string encAlgoServerToClient;
        private string macAlgoClientTOServer;
        private string macAlgoServerToClient;
        private string compAlgoClientToServer;
        private string compAlgoServerToClient;
        private string langClientToServer;
        private string langServerToClient;

        /// <summary>
        /// Gets or sets a value indicating whether the negotiation was successful.
        /// </summary>
        public bool NegotiateSuccessful
        {
            get { return this.negotiateSuccessful; }
            set { this.negotiateSuccessful = value; }
        }
        
        /// <summary>
        /// Gets or sets a value indicating whether the kex algorithms and server host
        /// key algorithms are agreed upon.
        /// </summary>
        public bool GuessOk 
        {
            get { return this.guessOk; }
            set { this.guessOk = value; }
        }
        
        /// <summary>
        /// Gets or sets the negotiated Key exchange algorithm.
        /// </summary>
        public string KexAlgo
        {
            get { return this.kexAlgo; }
            set { this.kexAlgo = value; }
        }
        
        /// <summary>
        /// Gets or sets the server host key algorithm.
        /// </summary>
        public string ServerHostkeyAlgo
        {
            get { return this.serverHostkeyAlgo; }
            set { this.serverHostkeyAlgo = value; }
        }
        
        /// <summary>
        /// Gets or sets the negotiated client to server encryption algorithm.
        /// </summary>
        public string EncAlgoClientToServer
        {
            get { return this.encAlgoClientToServer; }
            set { this.encAlgoClientToServer = value; }
        }
        
        /// <summary>
        /// Gets or sets the negotiated server to client encryption algorithm.
        /// </summary>
        public string EncAlgoServerToClient
        {
            get { return this.encAlgoServerToClient; }
            set { this.encAlgoServerToClient = value; }
        }

        /// <summary>
        /// Gets or sets the negotiated client to server MAC algorithm.
        /// </summary>
        public string MacAlgoClientTOServer
        {
            get { return this.macAlgoClientTOServer; }
            set { this.macAlgoClientTOServer = value; }
        }
        
        /// <summary>
        /// Gets or sets the negotiated server to client MAC algorithm.
        /// </summary>
        public string MacAlgoServerToClient 
        {
            get { return this.macAlgoServerToClient; }
            set { this.macAlgoServerToClient = value; }
        }
        
        /// <summary>
        /// Gets or sets the negotiated client to server compression algorithm.
        /// </summary>
        public string CompAlgoClientToServer
        {
            get { return this.compAlgoClientToServer; }
            set { this.compAlgoClientToServer = value; }
        }
        
        /// <summary>
        /// Gets or sets the negotiated server to client compression algorithm.
        /// </summary>
        public string CompAlgoServerToClient 
        {
            get { return this.compAlgoServerToClient; }
            set { this.compAlgoServerToClient = value; }
        }

        /// <summary>
        /// Gets or sets the negotiated client to server language.
        /// </summary>
        public string LangClientToServer
        {
            get { return this.langClientToServer; }
            set { this.langClientToServer = value; }
        }
        
        /// <summary>
        /// Gets or sets the negotiated server to client language.
        /// </summary>
        public string LangServerToClient
        {
            get { return this.langServerToClient; }
            set { this.langServerToClient = value; }
        }
    }
}
